==> python-keycloak-plus-0.0.3.tar.gz: python-keycloak-plus-0.0.3/keycloak/authorization/resource_set.py <==
# -*- coding: utf-8 -*-
#
# The MIT License (MIT)
#
# Copyright (C) 2019 Ume def <umedef@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


class ResourceSet:
    
    def __init__(self, name, displayName, scopes=None, attributes=None, uris=None, iconUri=None, ownerManagedAccess=False, typeName=None):
        self.name = name
        self.displayName = displayName
        self.ownerManagedAccess = ownerManagedAccess
        self.type = typeName
        self.scopes = scopes
        self.uris = uris
        self.attributes = attributes
        self.icon_uri = iconUri

==> python-keycloak-plus-0.0.17.tar.gz: python-keycloak-plus-0.0.17/keycloak/authorization/resource_set.py <==
# -*- coding: utf-8 -*-
#
# The MIT License (MIT)
#
# Copyright (C) 2019 Ume def <umedef@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


class ResourceSet:
    
    def __init__(self, name, displayName, scopes=None, attributes=None, uris=None, iconUri=None, ownerManagedAccess=False, typeName=None):
        self.name = name
        self.displayName = displayName
        self.ownerManagedAccess = ownerManagedAccess
        self.type = typeName
        self.scopes = scopes
        self.uris = uris
        self.attributes = attributes
        self.icon_uri = iconUri

    def toJson(self):
        return {
            "name": self.name, "displayName": self.displayName, "type": self.type, "ownerManagedAccess": str(self.__dict__["ownerManagedAccess"]).lower(), "attributes": self.attributes
        }
